@@ -1,11 +1,12 @@
 from pathlib import Path
 import uuid
 
-from pythonanywhere.api.webapp import Webapp
+from pythonanywhere_core.webapp import Webapp
+from snakesay import snakesay
+
 from pythonanywhere.exceptions import SanityException
 from pythonanywhere.virtualenvs import Virtualenv
 from pythonanywhere.launch_bash_in_virtualenv import launch_bash_in_virtualenv
-from pythonanywhere.snakesay import snakesay
 
 
 class Project:
