@@ -43,10 +43,10 @@ Example:
     pa_get_scheduled_task_specs 42 --logfile --no-spec"""
 
 from docopt import docopt
+from snakesay import snakesay
 from tabulate import tabulate
 
 from pythonanywhere.scripts_commons import ScriptSchema, get_logger, get_task_from_id
-from pythonanywhere.snakesay import snakesay
 
 
 def main(*, task_id, **kwargs):
